<?php
namespace Drupal\shop_evens\EventSubscriber;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Drupal\commerce_stock_local\Event\LocalStockTransactionEvent;
use Drupal\commerce_stock_local\Event\LocalStockTransactionEvents;

/**
 * Class ShopEvensLocalStockTransactionEvents.
 *
 * @package Drupal\shop_evens\ShopEvensLocalStockTransactionEvents
 */

class ShopEvensLocalStockTransactionEvents  implements EventSubscriberInterface {
  /**
   * Метод getSubscribedEvents() является обязательным и служит
   * для описания слушателей.
   */
  public static function getSubscribedEvents() {
    // Подписываемся на событие KernelEvents::REQUEST.
    // Когда событие произойдет, то запустится метод-слушатель onKernelRequestMaintenance в этом же классе.
    // 31 - приоритет слушателя.
    $events[LocalStockTransactionEvents::LOCAL_STOCK_TRANSACTION_INSERT][] = ['onStockTransactionInsert', 31];
    return $events;
  }

  /**
   * @param \Drupal\commerce_stock_local\Event\LocalStockTransactionEvent $event
   *
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  public function onStockTransactionInsert(LocalStockTransactionEvent $event) {
    /** @var \Drupal\commerce_product\Entity\ProductVariationInterface $variation */
    $variation = $event->getEntity();
    $stockManager = \Drupal::getContainer()->get('commerce_stock.service_manager');
    $stockLevel = $stockManager->getStockLevel($variation);
    $variation->set('field_cached_stock_level', $stockLevel);
    $variation->save();
  }

}
